@@ -191,6 +191,18 @@ uint16_t lfsr_digest16(uint8_t const message[], unsigned bytes, uint16_t gen, ui
 /// @param buffer_size number of bytes to process
 void ccitt_whitening(uint8_t *buffer, unsigned buffer_size);
 
+/// Apply IBM data whitening to a buffer.
+///
+/// The IBM data whitening process is built around a 9-bit Linear Feedback Shift Register (LFSR).
+/// CCITT data whitening processes data packets byte-per-byte, whereas IBM data
+/// whitening processes the data packet bit-per-bit
+/// Same, the initial value of the data whitening key is set to all ones, 0x1FF.
+/// s.a. https://www.nxp.com/docs/en/application-note/AN5070.pdf s.5.1
+///
+/// @param buffer bytes of message data
+/// @param buffer_size number of bytes to process
+void ibm_whitening(uint8_t *buffer, unsigned buffer_size);
+
 /// Compute bit parity of a single byte (8 bits).
 ///
 /// @param byte single byte to check
