@@ -10,7 +10,8 @@
 #include "r_device.h"
 #include "bitbuffer.h"
 #include "data.h"
-#include "util.h"
+#include "bit_util.h"
 #include "decoder_util.h"
+#include "c_util.h"
 
 #endif /* INCLUDE_DECODER_H_ */
