@@ -169,7 +169,7 @@ static int holman_ws5029pcm_decode(r_device *decoder, bitbuffer_t *bitbuffer)
                 "rain_mm",          "Total rainfall",   DATA_FORMAT, "%.1f mm",   DATA_DOUBLE, rain_mm,
                 "wind_avg_km_h",    "Wind avg speed",   DATA_FORMAT, "%.1f km/h", DATA_DOUBLE, speed_kmh,
                 "wind_dir_deg",     "Wind Direction",   DATA_INT,                              direction_deg,
-                "uv",               "UV Index",         DATA_FORMAT, "%u",        DATA_INT,    uv_index,
+                "uvi",              "UV Index",         DATA_FORMAT, "%.0f",      DATA_DOUBLE, (double)uv_index,
                 "light_lux",        "Lux",              DATA_FORMAT, "%u",        DATA_INT,    light_lux,
                 "counter",          "Counter",          DATA_FORMAT, "%u",        DATA_INT,    counter,
                 "battery_ok",       "battery",          DATA_FORMAT, "%u",        DATA_INT,    !battery_low,
@@ -192,7 +192,7 @@ static char const *const output_fields[] = {
         "rain_mm",
         "wind_avg_km_h",
         "wind_dir_deg",
-        "uv",
+        "uvi",
         "light_lux",
         "counter",
         "mic",
