@@ -173,7 +173,7 @@ static int lacrosse_tx141x_decode(r_device *decoder, bitbuffer_t *bitbuffer)
                     "model",            "",                 DATA_STRING, "LaCrosse-TX141W",
                     "id",               "Sensor ID",        DATA_FORMAT, "%05x", DATA_INT, id,
                     "channel",          "Channel",          DATA_FORMAT, "%01x", DATA_INT, channel,
-                    "battery_ok",       "Battery level",    DATA_INT,    !battery_low,
+                    "battery_ok",       "Battery",          DATA_INT,    !battery_low,
                     "temperature_C",    "Temperature",      DATA_FORMAT, "%.2f C", DATA_DOUBLE, temp_c,
                     "humidity",         "Humidity",         DATA_FORMAT, "%u %%", DATA_INT, humidity,
                     "test",             "Test?",            DATA_INT,    test,
@@ -191,7 +191,7 @@ static int lacrosse_tx141x_decode(r_device *decoder, bitbuffer_t *bitbuffer)
                     "model",            "",                 DATA_STRING, "LaCrosse-TX141W",
                     "id",               "Sensor ID",        DATA_FORMAT, "%05x", DATA_INT, id,
                     "channel",          "Channel",          DATA_FORMAT, "%01x", DATA_INT, channel,
-                    "battery_ok",       "Battery level",    DATA_INT,    !battery_low,
+                    "battery_ok",       "Battery",          DATA_INT,    !battery_low,
                     "wind_avg_km_h",    "Wind speed",       DATA_FORMAT, "%.1f km/h",  DATA_DOUBLE, speed_kmh,
                     "wind_dir_deg",     "Wind direction",   DATA_INT,    humidity,
                     "test",             "Test?",            DATA_INT,    test,
