@@ -144,7 +144,7 @@ static int rojaflex_decode(r_device *decoder, bitbuffer_t *bitbuffer)
         }
     }
 
-    char *cmd_str = "unknown";
+    char const *cmd_str = "unknown";
     switch (msg[COMMAND_ID_OFFSET]) {
     case COMMAND_ID_STOP:
         cmd_str = "Stop"; break;
@@ -284,7 +284,7 @@ static int rojaflex_decode(r_device *decoder, bitbuffer_t *bitbuffer)
     return 1;
 }
 
-static char *output_fields[] = {
+static char const *const output_fields[] = {
         "model",
         "id",
         "channel",
@@ -296,7 +296,7 @@ static char *output_fields[] = {
         NULL,
 };
 
-r_device rojaflex = {
+r_device const rojaflex = {
         .name        = "RojaFlex shutter and remote devices",
         .modulation  = FSK_PULSE_PCM,
         .short_width = 100,
