@@ -42,12 +42,10 @@ Packet nibbles:
 
 static int tpms_hyundai_vdo_decode(r_device *decoder, bitbuffer_t *bitbuffer, unsigned row, unsigned bitpos)
 {
-    data_t *data;
     bitbuffer_t packet_bits = {0};
     uint8_t *b;
     int state;
     unsigned id;
-    char id_str[9 + 1];
     int flags;
     int repeat;
     int pressure;
@@ -80,10 +78,11 @@ static int tpms_hyundai_vdo_decode(r_device *decoder, bitbuffer_t *bitbuffer, un
     temperature   = b[7];
     maybe_battery = b[8];
 
-    sprintf(id_str, "%08x", id);
+    char id_str[9 + 1];
+    snprintf(id_str, sizeof(id_str), "%08x", id);
 
     /* clang-format off */
-    data = data_make(
+    data_t *data = data_make(
             "model",            "",             DATA_STRING, "Hyundai-VDO",
             "type",             "",             DATA_STRING, "TPMS",
             "id",               "",             DATA_STRING, id_str,
@@ -128,7 +127,7 @@ static int tpms_hyundai_vdo_callback(r_device *decoder, bitbuffer_t *bitbuffer)
     return events > 0 ? events : ret;
 }
 
-static char *output_fields[] = {
+static char const *const output_fields[] = {
         "model",
         "type",
         "id",
@@ -142,7 +141,7 @@ static char *output_fields[] = {
         NULL,
 };
 
-r_device tpms_hyundai_vdo = {
+r_device const tpms_hyundai_vdo = {
         .name        = "Hyundai TPMS (VDO)",
         .modulation  = FSK_PULSE_PCM,
         .short_width = 52,  // in the FCC test protocol is actually 42us, but works with 52 also
