@@ -51,11 +51,11 @@ static int visonic_powercode_decode(r_device *decoder, bitbuffer_t *bitbuffer)
     uint8_t msg[32];
     uint8_t lrc;
 
-    // 37 bits expected, 6 packet repetitions, accept 4
-    int row = bitbuffer_find_repeated_row(bitbuffer, 4, 37);
+    // 37 bits expected, 6 packet repetitions, accept 2
+    int row = bitbuffer_find_repeated_row(bitbuffer, 2, 37);
 
     // exit if anything other than one row returned (-1 if failed)
-    if (row != 0)
+    if (row == -1)
         return DECODE_ABORT_LENGTH;
 
     // exit if incorrect number of bits in row or none
