@@ -44,17 +44,16 @@ RMS18, Radio Shack 61-2675-T
 
 static int x10_rf_callback(r_device *decoder, bitbuffer_t *bitbuffer)
 {
-    data_t *data;
     uint8_t *b = bitbuffer->bb[1];
 
-    uint8_t arrbKnownConstBitMask[4]  = {0x0B, 0x0B, 0x07, 0x07};
-    uint8_t arrbKnownConstBitValue[4] = {0x00, 0x0B, 0x00, 0x07};
+    uint8_t const arrbKnownConstBitMask[4]  = {0x0B, 0x0B, 0x07, 0x07};
+    uint8_t const arrbKnownConstBitValue[4] = {0x00, 0x0B, 0x00, 0x07};
 
     // Row [0] is sync pulse
     // Validate length
     if (bitbuffer->bits_per_row[1] != 32) { // Don't waste time on a wrong length package
         if (bitbuffer->bits_per_row[1] != 0)
-            decoder_logf(decoder, 1, __func__, "DECODE_ABORT_LENGTH, Received message length=%i", bitbuffer->bits_per_row[1]);
+            decoder_logf(decoder, 1, __func__, "DECODE_ABORT_LENGTH, Received message length=%d", bitbuffer->bits_per_row[1]);
         return DECODE_ABORT_LENGTH;
     }
 
@@ -131,10 +130,10 @@ static int x10_rf_callback(r_device *decoder, bitbuffer_t *bitbuffer)
     }
 
     // debug output
-    decoder_logf_bitbuffer(decoder, 1, __func__, bitbuffer, "id=%s%i event_str=%s", housecode, bDeviceCode, event_str);
+    decoder_logf_bitbuffer(decoder, 1, __func__, bitbuffer, "id=%s%d event_str=%s", housecode, bDeviceCode, event_str);
 
     /* clang-format off */
-    data = data_make(
+    data_t *data = data_make(
             "model",        "",             DATA_STRING, "X10-RF",
             "id",           "",             DATA_INT,    bDeviceCode,
             "channel",      "",             DATA_STRING, housecode,
