@@ -71,6 +71,18 @@ void pulse_detect_free(pulse_detect_t *pulse_detect)
     free(pulse_detect);
 }
 
+void pulse_detect_reset(pulse_detect_t *pulse_detect)
+{
+    pulse_detect->ook_state         = PD_OOK_STATE_IDLE;
+    pulse_detect->pulse_length      = 0;
+    pulse_detect->max_pulse         = 0;
+    pulse_detect->data_counter      = 0;
+    pulse_detect->lead_in_counter   = 0;
+    pulse_detect->ook_low_estimate  = 0;
+    pulse_detect->ook_high_estimate = 0;
+    pulse_detect_fsk_init(&pulse_detect->pulse_detect_fsk);
+}
+
 void pulse_detect_set_levels(pulse_detect_t *pulse_detect, int use_mag_est, float fixed_high_level, float min_high_level, float high_low_ratio, int verbosity)
 {
     pulse_detect->use_mag_est = use_mag_est;
@@ -206,7 +218,7 @@ int pulse_detect_package(pulse_detect_t *pulse_detect, int16_t const *envelope_d
             int att = pulse_detect->use_mag_est ? mag_to_att(am_n) : amp_to_att(am_n);
             att_hist[att] += 1;
         }
-        int16_t ook_threshold = (s->ook_low_estimate + s->ook_high_estimate) / 2;
+        int16_t ook_threshold = (s->ook_low_estimate + MIN(s->ook_high_estimate, OOK_MAX_HIGH_LEVEL)) / 2;
         if (pulse_detect->ook_fixed_high_level != 0) {
             ook_threshold = pulse_detect->ook_fixed_high_level; // Manual override
         }
@@ -239,7 +251,6 @@ int pulse_detect_package(pulse_detect_t *pulse_detect, int16_t const *envelope_d
                     // Calculate default OOK high level estimate
                     s->ook_high_estimate = pulse_detect->ook_high_low_ratio * s->ook_low_estimate; // Default is a ratio of low level
                     s->ook_high_estimate = MAX(s->ook_high_estimate, pulse_detect->ook_min_high_level);
-                    s->ook_high_estimate = MIN(s->ook_high_estimate, OOK_MAX_HIGH_LEVEL);
                     if (s->lead_in_counter <= OOK_EST_LOW_RATIO) s->lead_in_counter += 1;        // Allow initial estimate to settle
                 }
                 break;
@@ -271,7 +282,6 @@ int pulse_detect_package(pulse_detect_t *pulse_detect, int16_t const *envelope_d
                     // Calculate OOK high level estimate
                     s->ook_high_estimate += am_n / OOK_EST_HIGH_RATIO - s->ook_high_estimate / OOK_EST_HIGH_RATIO;
                     s->ook_high_estimate = MAX(s->ook_high_estimate, pulse_detect->ook_min_high_level);
-                    s->ook_high_estimate = MIN(s->ook_high_estimate, OOK_MAX_HIGH_LEVEL);
                     // Estimate pulse carrier frequency
                     pulses->fsk_f1_est += fm_data[s->data_counter] / OOK_EST_HIGH_RATIO - pulses->fsk_f1_est / OOK_EST_HIGH_RATIO;
                 }
